@@ -90,6 +90,18 @@ class ADCBaseElement:
             "Initialized %s (%s) %s", self.device_type, self._family_raw, self.name
         )
 
+    @property
+    def read_only(self) -> bool | None:
+        """Return whether logged in user has permission to peek in."""
+        return (
+            not result
+            if isinstance(
+                (result := self._attribs_raw.get("hasPermissionToChangeState")),
+                bool,
+            )
+            else None
+        )
+
     class DeviceState(Enum):
         """Placeholder for child device states."""
 
@@ -193,6 +205,11 @@ class ADCSystem(ADCBaseElement):
         """Return whether device is malfunctioning."""
         return None
 
+    @property
+    def read_only(self) -> None:
+        """Non-actionable object."""
+        return
+
 
 class ADCPartition(DesiredStateMixin, ADCBaseElement):
     """Represent Alarm.com partition element."""
@@ -435,6 +452,11 @@ class ADCSensor(ADCBaseElement):
         except ValueError:
             return None
 
+    @property
+    def read_only(self) -> None:
+        """Non-actionable object."""
+        return
+
 
 class ADCGarageDoor(DesiredStateMixin, ADCBaseElement):
     """Represent Alarm.com garage door element."""
